@@ -112,8 +112,9 @@ sub fileHandle
 
         # if we already have a file handle defined, return it
         return $self->{_filehandle}
-            if (defined $self->{_filehandle}
-                and $self->{_filehandle}->isa("IO::File"));
+            if (    defined $self->{_filehandle}
+                and $self->{_filehandle}->isa("IO::File")
+                and defined fileno($self->{_filehandle}));
 
         # generate file name
         my $filename = catdir($self->{dir}, $self->{file});
@@ -217,14 +218,6 @@ sub DESTROY
 
 }          # DESTROY
 
-=head1 SEE ALSO
-
-L<perl>, L<Log::Fine>, L<Log::Fine::Handle>
-
-=head1 AUTHOR
-
-Christopher M. Fuhrman, C<< <cfuhrman at panix.com> >>
-
 =head1 BUGS
 
 Please report any bugs or feature requests to
@@ -263,7 +256,15 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 REVISION INFORMATION
 
-  $Id: a84b73b64f92e309beef02fd544bec62d621c064 $
+  $Id: 7d48f55551c9b717fcea78f283b1ddfccff37d8a $
+
+=head1 AUTHOR
+
+Christopher M. Fuhrman, C<< <cfuhrman at panix.com> >>
+
+=head1 SEE ALSO
+
+L<perl>, L<Log::Fine>, L<Log::Fine::Handle>
 
 =head1 COPYRIGHT & LICENSE
 
